@@ -1,227 +1,233 @@
+#!/bin/false
+
 #
 # BZ::Client::Bug - Client side representation of a bug in Bugzilla
 #
 
 use strict;
-use warnings "all";
+use warnings 'all';
 
 package BZ::Client::Bug;
-
+$BZ::Client::Bug::VERSION = '1.062_1';
 use BZ::Client::API();
 
-our $VERSION = 1.0;
 our @ISA = qw(BZ::Client::API);
 
-sub legal_values($$$) {
+sub legal_values {
     my($class, $client, $field) = @_;
-    $client->log("debug", "BZ::Client::Bug::legal_values: Asking for $field");
-    my $params = { "field" => $field };
-    my $result = $class->api_call($client, "Bug.legal_values", $params);
-    my $values = $result->{"values"};
-    if (!$values  ||  "ARRAY" ne ref($values)) {
+    $client->log('debug', "BZ::Client::Bug::legal_values: Asking for $field");
+    my $params = { 'field' => $field };
+    my $result = $class->api_call($client, 'Bug.legal_values', $params);
+    my $values = $result->{'values'};
+    if (!$values  ||  'ARRAY' ne ref($values)) {
         $class->error($client, "Invalid reply by server, expected array of values.");
     }
-    $client->log("debug", "BZ::Client::Bug::legal_values: Got " . join(",", @$values));
+    $client->log('debug', 'BZ::Client::Bug::legal_values: Got ' . join(',', @$values));
     return $values;
 }
 
-sub get($$;$) {
+sub get {
     my($class, $client, $ids, $permissive) = @_;
-    $client->log("debug", "BZ::Client::Bug::get: Asking for " . (ref($ids) eq "ARRAY" ? join(",", @$ids) : $ids));
+    $client->log('debug', 'BZ::Client::Bug::get: Asking for ' . (ref($ids) eq 'ARRAY' ? join(',', @$ids) : $ids));
     my $params = { ids => $ids };
-    $params->{"permissive"} = BZ::Client::XMLRPC::boolean::TRUE() if $permissive;
-    my $result = $class->api_call("Bug.get", $params);
-    my $bugs = $result->{"bugs"};
-    if (!$bugs  ||  "ARRAY" ne ref($bugs)) {
-        $class->error($client, "Invalid reply by server, expected array of bugs.");
+    $params->{'permissive'} = BZ::Client::XMLRPC::boolean::TRUE() if $permissive;
+    my $result = $class->api_call($client, 'Bug.get', $params);
+    my $bugs = $result->{'bugs'};
+    if (!$bugs  ||  'ARRAY' ne ref($bugs)) {
+        $class->error($client, 'Invalid reply by server, expected array of bugs.');
     }
     my @result;
-    foreach my $bug (@$bugs) {
+    for my $bug (@$bugs) {
         push(@result, BZ::Client::Bug->new(%$bug));
     }
-    $client->log("debug", "BZ::Client::Bug::get: Got " . scalar(@result));
-    return \@result;
+    $client->log('debug', 'BZ::Client::Bug::get: Got ' . scalar(@result));
+    return wantarray ? @result : \@result;
 }
 
-sub search($$$) {
+sub search {
     my($class, $client, $params) = @_;
-    $client->log("debug", "BZ::Client::Bug::search: Searching");
-    my $result = $class->api_call($client, "Bug.search", $params);
-    my $bugs = $result->{"bugs"};
-    if (!$bugs  ||  "ARRAY" ne ref($bugs)) {
-        $class->error($client, "Invalid reply by server, expected array of bugs.");
+    $client->log('debug', 'BZ::Client::Bug::search: Searching');
+    my $result = $class->api_call($client, 'Bug.search', $params);
+    my $bugs = $result->{'bugs'};
+    if (!$bugs  ||  'ARRAY' ne ref($bugs)) {
+        $class->error($client, 'Invalid reply by server, expected array of bugs.');
     }
     my @result;
-    foreach my $bug (@$bugs) {
+    for my $bug (@$bugs) {
         push(@result, BZ::Client::Bug->new(%$bug));
     }
-    $client->log("debug", "BZ::Client::Bug::search: Got " . scalar(@result));
-    return \@result;
+    $client->log('debug', 'BZ::Client::Bug::search: Got ' . scalar(@result));
+    return wantarray ? @result : \@result;
 }
 
-sub create($$$) {
+sub create {
     my($class, $client, $params) = @_;
-    $client->log("debug", "BZ::Client::Bug::create: Creating");
+    $client->log('debug', 'BZ::Client::Bug::create: Creating');
     my $result = $class->api_call($client, "Bug.create", $params);
     my $id = $result->{"id"};
     if (!$id) {
-        $class->error($client, "Invalid reply by server, expected bug ID.");
+        $class->error($client, 'Invalid reply by server, expected bug ID.');
     }
     return $id;
 }
 
-sub new($@) {
+sub new {
     my $class = shift;
     my $self = { @_ };
     bless($self, ref($class) || $class);
     return $self;
 }
 
-sub id($;$) {
+sub id {
     my $self = shift;
     if (@_) {
-        $self->{"id"} = shift;
+        $self->{'id'} = shift;
     } else {
-        return $self->{"id"}
+        return $self->{'id'}
     }
 }
 
-sub alias($;$) {
+sub alias {
     my $self = shift;
     if (@_) {
-        $self->{"alias"} = shift;
+        $self->{'alias'} = shift;
     } else {
-        return $self->{"alias"}
+        return $self->{'alias'}
     }
 }
 
-sub assigned_to($;$) {
+sub assigned_to {
     my $self = shift;
     if (@_) {
-        $self->{"assigned_to"} = shift;
+        $self->{'assigned_to'} = shift;
     } else {
-        return $self->{"assigned_to"}
+        return $self->{'assigned_to'}
     }
 }
 
-sub component($;$) {
+sub component {
     my $self = shift;
     if (@_) {
-        $self->{"component"} = shift;
+        $self->{'component'} = shift;
     } else {
-        return $self->{"component"}
+        return $self->{'component'}
     }
 }
 
-sub creation_time($;$) {
+sub creation_time {
     my $self = shift;
     if (@_) {
-        $self->{"creation_time"} = shift;
+        $self->{'creation_time'} = shift;
     } else {
-        return $self->{"creation_time"}
+        return $self->{'creation_time'}
     }
 }
 
-sub dupe_of($;$) {
+sub dupe_of {
     my $self = shift;
     if (@_) {
-        $self->{"dupe_of"} = shift;
+        $self->{'dupe_of'} = shift;
     } else {
-        return $self->{"dupe_of"}
+        return $self->{'dupe_of'}
     }
 }
 
-sub internals($;$) {
+sub internals {
     my $self = shift;
     if (@_) {
-        $self->{"internals"} = shift;
+        $self->{'internals'} = shift;
     } else {
-        return $self->{"internals"}
+        return $self->{'internals'}
     }
 }
 
-sub is_open($;$) {
+sub is_open {
     my $self = shift;
     if (@_) {
-        $self->{"is_open"} = shift;
+        $self->{'is_open'} = shift;
     } else {
-        return $self->{"is_open"}
+        return $self->{'is_open'}
     }
 }
 
-sub last_change_time($;$) {
+sub last_change_time {
     my $self = shift;
     if (@_) {
-        $self->{"last_change_time"} = shift;
+        $self->{'last_change_time'} = shift;
     } else {
-        return $self->{"last_change_time"}
+        return $self->{'last_change_time'}
     }
 }
 
-sub priority($;$) {
+sub priority {
     my $self = shift;
     if (@_) {
-        $self->{"priority"} = shift;
+        $self->{'priority'} = shift;
     } else {
-        return $self->{"priority"}
+        return $self->{'priority'}
     }
 }
 
-sub product($;$) {
+sub product {
     my $self = shift;
     if (@_) {
-        $self->{"product"} = shift;
+        $self->{'product'} = shift;
     } else {
-        return $self->{"product"}
+        return $self->{'product'}
     }
 }
 
-sub resolution($;$) {
+sub resolution {
     my $self = shift;
     if (@_) {
-        $self->{"resolution"} = shift;
+        $self->{'resolution'} = shift;
     } else {
-        return $self->{"resolution"}
+        return $self->{'resolution'}
     }
 }
 
-sub severity($;$) {
+sub severity {
     my $self = shift;
     if (@_) {
-        $self->{"severity"} = shift;
+        $self->{'severity'} = shift;
     } else {
-        return $self->{"severity"}
+        return $self->{'severity'}
     }
 }
 
-sub status($;$) {
+sub status {
     my $self = shift;
     if (@_) {
-        $self->{"status"} = shift;
+        $self->{'status'} = shift;
     } else {
-        return $self->{"status"}
+        return $self->{'status'}
     }
 }
 
-sub summary($;$) {
+sub summary {
     my $self = shift;
     if (@_) {
-        $self->{"summary"} = shift;
+        $self->{'summary'} = shift;
     } else {
-        return $self->{"summary"}
+        return $self->{'summary'}
     }
 }
 
 1;
 
+__END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-  BZ::Client::Bug - Client side representation of a bug in Bugzilla 
+BZ::Client::Bug
 
-This class provides methods for accessing and managing bugs in Bugzilla.
+=head1 VERSION
 
+version 1.062_1
 
 =head1 SYNOPSIS
 
@@ -230,6 +236,16 @@ This class provides methods for accessing and managing bugs in Bugzilla.
                                "password" => $password);
   my $bugs = BZ::Client::Bug->get($client, $ids);
 
+=head1 NAME
+
+  BZ::Client::Bug - Client side representation of a bug in Bugzilla
+
+=head1 VERSION
+
+version 1.062_1
+
+This class provides methods for accessing and managing bugs in Bugzilla.
+
 =head1 CLASS METHODS
 
 This section lists the class methods, which are available in this module.
@@ -363,8 +379,19 @@ Gets or sets the current status of the bug.
 
 Gets or sets the summary of this bug.
 
-
 =head1 SEE ALSO
 
   L<BZ::Client>, L<BZ::Client::API>
- 
\ No newline at end of file
+
+=head1 AUTHOR
+
+Dean Hamstead <dean@bytefoundry.com.au>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Dean Hamstad.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
