@@ -6,19 +6,18 @@ use strict;
 use warnings "all";
 
 package BZ::Client::Bugzilla;
-
+$BZ::Client::Bugzilla::VERSION = '1.062_1';
 use BZ::Client::API();
 
-our $VERSION = 1.0;
 our @ISA = qw(BZ::Client::API);
 
-sub extensions($$) {
+sub extensions {
     my($class, $client) = @_;
     my $params = {};
     return $class->api_call($client, "Bugzilla.extensions", $params);
 }
 
-sub time($$) {
+sub time {
     my($class, $client) = @_;
     my $params = {};
     $client->log("debug", "BZ::Client::Bugzilla::time: Asking");
@@ -27,7 +26,7 @@ sub time($$) {
     return $time;
 }
 
-sub timezone($$) {
+sub timezone {
     my($class, $client) = @_;
     my $params = {};
     $client->log("debug", "BZ::Client::Bugzilla::timezone: Asking");
@@ -36,7 +35,7 @@ sub timezone($$) {
     return $timezone;
 }
 
-sub version($$) {
+sub version {
     my($class, $client) = @_;
     my $params = {};
     $client->log("debug", "BZ::Client::Bugzilla::version: Asking");
@@ -48,15 +47,19 @@ sub version($$) {
 
 1;
 
+__END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-  BZ::Client::Bugzilla - Provides information about the Bugzilla server.
+BZ::Client::Bugzilla
 
-This class provides methods for accessing information about the Bugzilla
-servers installation.
+=head1 VERSION
 
+version 1.062_1
 
 =head1 SYNOPSIS
 
@@ -67,6 +70,17 @@ servers installation.
   my $time = BZ::Client::Bugzilla->time($client);
   my $version = BZ::Client::Bugzilla->version($client);
 
+=head1 NAME
+
+  BZ::Client::Bugzilla - Provides information about the Bugzilla server.
+
+=head1 VERSION
+
+version 1.062_1
+
+This class provides methods for accessing information about the Bugzilla
+servers installation.
+
 =head1 CLASS METHODS
 
 This section lists the class methods, which are available in this module.
@@ -96,8 +110,19 @@ is deprecated: Use L</time> instead.
 
 Returns the Bugzilla servers version.
 
-
 =head1 SEE ALSO
 
   L<BZ::Client>, L<BZ::Client::API>
- 
\ No newline at end of file
+
+=head1 AUTHOR
+
+Dean Hamstead <dean@bytefoundry.com.au>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Dean Hamstad.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
