@@ -6,13 +6,12 @@ use strict;
 use warnings "all";
 
 package BZ::Client::Product;
-
+$BZ::Client::Product::VERSION = '1.062_1';
 use BZ::Client::API();
 
-our $VERSION = 1.0;
 our @ISA = qw(BZ::Client::API);
 
-sub get_selectable_products($$) {
+sub get_selectable_products {
     my($class, $client) = @_;
     $client->log("debug", "BZ::Client::Product::get_selectable_products: Asking");
     my $result = $class->get_list("Product.get_selectable_products", $client);
@@ -20,7 +19,7 @@ sub get_selectable_products($$) {
     return $result;
 }
 
-sub get_enterable_products($$) {
+sub get_enterable_products {
     my($class, $client) = @_;
     $client->log("debug", "BZ::Client::Product::get_enterable_products: Asking");
     my $result = $class->get_list("Product.get_enterable_products", $client);
@@ -28,7 +27,7 @@ sub get_enterable_products($$) {
     return $result;
 }
 
-sub get_accessible_products($$) {
+sub get_accessible_products {
     my($class, $client) = @_;
     $client->log("debug", "BZ::Client::Product::get_accessible_products: Asking");
     my $result = $class->get_list("Product.get_accessible_products", $client);
@@ -36,7 +35,7 @@ sub get_accessible_products($$) {
     return $result;
 }
 
-sub get_list($$$) {
+sub get_list {
     my($class, $methodName, $client) = @_;
     my $result = $class->api_call($client, $methodName, {});
     my $ids = $result->{"ids"};
@@ -46,7 +45,7 @@ sub get_list($$$) {
     return $ids;
 }
 
-sub get($$$) {
+sub get {
     my($class, $client, $ids) = @_;
     my $result = $class->api_call($client, "Product.get", { "ids" => $ids });
     my $products = $result->{"products"};
@@ -63,14 +62,14 @@ sub get($$$) {
     return \@result;
 }
 
-sub new($@) {
+sub new {
     my $class = shift;
     my $self = { @_ };
     bless($self, ref($class) || $class);
     return $self;
 }
 
-sub id($;$) {
+sub id {
     my $self = shift;
     if (@_) {
         $self->{"id"} = shift;
@@ -79,7 +78,7 @@ sub id($;$) {
     }
 }
 
-sub name($;$) {
+sub name {
     my $self = shift;
     if (@_) {
         $self->{"name"} = shift;
@@ -88,7 +87,7 @@ sub name($;$) {
     }
 }
 
-sub description($;$) {
+sub description {
     my $self = shift;
     if (@_) {
         $self->{"description"} = shift;
@@ -97,7 +96,7 @@ sub description($;$) {
     }
 }
 
-sub internals($;$) {
+sub internals {
     my $self = shift;
     if (@_) {
         $self->{"internals"} = shift;
@@ -108,15 +107,19 @@ sub internals($;$) {
 
 1;
 
+__END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-  BZ::Client::Product - Client side representation of a product in Bugzilla 
+BZ::Client::Product
 
-This class provides methods for accessing and managing products in Bugzilla. Instances
-of this class are returned by L<BZ::Client::Product::get>.
+=head1 VERSION
 
+version 1.062_1
 
 =head1 SYNOPSIS
 
@@ -126,6 +129,17 @@ of this class are returned by L<BZ::Client::Product::get>.
   my $ids = BZ::Client::Product->get_accessible_products($client);
   my $products = BZ::Client::Product->get($client, $ids);
 
+=head1 NAME
+
+  BZ::Client::Product - Client side representation of a product in Bugzilla
+
+=head1 VERSION
+
+version 1.062_1
+
+This class provides methods for accessing and managing products in Bugzilla. Instances
+of this class are returned by L<BZ::Client::Product::get>.
+
 =head1 CLASS METHODS
 
 This section lists the class methods, which are available in this module.
@@ -145,7 +159,7 @@ Returns a list of the ids of the products the user can enter bugs against.
 =head2 get_accessible_products
 
   my @products = BZ::Client::Product->get_selectable_products($client);
-  
+
 Returns a list of the ids of the products the user can search or enter bugs against.
 
 =head2 get
@@ -192,4 +206,15 @@ Gets or sets the products description.
 
   L<BZ::Client>, L<BZ::Client::API>
 
- 
\ No newline at end of file
+=head1 AUTHOR
+
+Dean Hamstead <dean@bytefoundry.com.au>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Dean Hamstad.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
