@@ -1,21 +1,23 @@
+#!/bin/false
+
 #
 #  BZ::Client::Test - Module for writing integration tests
 #
 
 use strict;
-use warnings "all";
+use warnings 'all';
 
 package BZ::Client::Test;
-
+$BZ::Client::Test::VERSION = '1.062_1';
 use BZ::Client();
 
 
-sub new($;@) {
+sub new {
     my $class = shift;
     my $self;
     if (@_ == 1) {
         my $files = shift;
-        foreach my $f (@$files) {
+        for my $f (@$files) {
             if (-f $f) {
                 my $hash;
                 eval {
@@ -24,7 +26,7 @@ sub new($;@) {
                 if ($@) {
                     die "Failed to load configuration file $f: $@";
                 }
-                if (!$hash  ||  ref($hash) ne "HASH") {
+                if (!$hash  ||  ref($hash) ne 'HASH') {
                     die "Configuration file $f didn't return a HASH value.";
                 }
                 # Create a copy of $hash
@@ -39,7 +41,7 @@ sub new($;@) {
     return $self;
 }
 
-sub testUrl($;$) {
+sub testUrl {
     my $self = shift;
     if (@_) {
         $self->{'testUrl'} = shift;
@@ -48,7 +50,7 @@ sub testUrl($;$) {
     }
 }
 
-sub testUser($;$) {
+sub testUser {
     my $self = shift;
     if (@_) {
         $self->{'testUser'} = shift;
@@ -57,7 +59,7 @@ sub testUser($;$) {
     }
 }
 
-sub testPassword($;$) {
+sub testPassword {
     my $self = shift;
     if (@_) {
         $self->{'testPassword'} = shift;
@@ -66,7 +68,7 @@ sub testPassword($;$) {
     }
 }
 
-sub logDirectory($;$) {
+sub logDirectory {
     my $self = shift;
     if (@_) {
         $self->{'logDirectory'} = shift;
@@ -75,7 +77,7 @@ sub logDirectory($;$) {
     }
 }
 
-sub client($) {
+sub client {
     my $self = shift;
     if ($self->isSkippingIntegrationTests()) {
         die "Unable to create a client, as integration tests are being skipped.";
@@ -86,18 +88,26 @@ sub client($) {
                            "logDirectory" => $self->logDirectory());
 }
 
-sub isSkippingIntegrationTests($) {
+sub isSkippingIntegrationTests {
     my $self = shift;
     return !defined($self->testUrl());
 }
 
 1;
 
+__END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-  BZ::Client::Test - Module for writing integration tests
+BZ::Client::Test
+
+=head1 VERSION
+
+version 1.062_1
 
 =head1 SYNOPSIS
 
@@ -112,6 +122,14 @@ sub isSkippingIntegrationTests($) {
     # Run the tests, using the given client.
   }
 
+=head1 NAME
+
+  BZ::Client::Test - Module for writing integration tests
+
+=head1 VERSION
+
+version 1.062_1
+
 =head1 CLASS METHODS
 
 This section lists the class methods.
@@ -175,8 +193,19 @@ Creates an instance of BZ::Client, using the testers configuration.
 An exception is thrown, if the tester is unable to create a client
 object, because integration tests are being skipped.
 
-
 =head1 SEE ALSO
 
   L<BZ::Client>
 
+=head1 AUTHOR
+
+Dean Hamstead <dean@bytefoundry.com.au>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Dean Hamstad.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
